@@ -22,7 +22,7 @@ summary.netSimulator <- function(object, digits = 2, ...){
   # Summarize per case:
   suppressWarnings({
   df <- object %>% dplyr::select(.data[["sensitivity"]],.data[["specificity"]],.data[["correlation"]],.data[["strength"]],.data[["closeness"]],.data[["betweenness"]],all_of(Conditions)) %>% 
-    dplyr::group_by_at(Conditions) %>% dplyr::summarize_each(funs(fun(.,digits=digits))) %>% 
+    dplyr::group_by(across(all_of(Conditions))) %>% dplyr::summarize(across(everything(), ~fun(., digits=digits))) %>% 
     dplyr::arrange(.data[['nCases']]) %>% as.data.frame
   })
   
@@ -66,15 +66,18 @@ plot.netSimulator <- function(x, xvar = "factor(nCases)",
   }
   
   # Gather:
-  Gathered <- x %>% 
+  Gathered <- x %>%
     tidyr::gather("measure","value",yvar)
-  
+
+  # Evaluate xvar expression (e.g., "factor(nCases)") into a column:
+  Gathered[[".xvar"]] <- eval(parse(text = xvar), envir = Gathered)
+
   # AES:
   if (!is.null(color)){
     Gathered[[color]] <- as.factor(Gathered[[color]])
-    AES <- ggplot2::aes_string(x=xvar,y="value",fill=color)
+    AES <- ggplot2::aes(x=.data[[".xvar"]],y=.data[["value"]],fill=.data[[color]])
   } else {
-    AES <- ggplot2::aes_string(x=xvar,y="value")
+    AES <- ggplot2::aes(x=.data[[".xvar"]],y=.data[["value"]])
   }
   
   # Create plot:
