@@ -21,7 +21,14 @@ parSim <- function(
   
   # Exclude cases:
   if (!missing(exclude)){
-    AllConditions <- AllConditions %>% filter_(.dots = exclude)
+    for (ex in exclude){
+      if (inherits(ex, "formula")){
+        ex <- ex[[length(ex)]]
+      } else {
+        ex <- rlang::parse_expr(ex)
+      }
+      AllConditions <- AllConditions %>% filter(!!ex)
+    }
   }
   
   
@@ -45,14 +52,15 @@ parSim <- function(
     ######################
     ## use Socket clusters
     if (!debug){
-      cl <- snow::makeSOCKcluster(nClust)  
+      cl <- snow::makeSOCKcluster(nClust)
     } else {
       cl <- snow::makeSOCKcluster(nClust, outfile = "clusterLOG.txt")
     }
-    
+    on.exit(stopCluster(cl), add = TRUE)
+
     #     # Start clusters:
     #     cl <- makeCluster(getOption("cl.cores", nCores))
-    #     
+    #
     # Export the sim conditions:
     clusterExport(cl, c("AllConditions","expr","debug"), envir = environment())
     
@@ -79,9 +87,6 @@ parSim <- function(
       df$errorMessage <- ''
       df
     }, cl = cl)
-    
-    # Stop the cluster:
-    stopCluster(cl)
   } else {
     # Export:
     if (!missing(export)){
